package com.fr.plugin.xxxx.sso;

import com.fr.data.NetworkHelper;
import com.fr.decision.authority.data.User;
import com.fr.decision.mobile.terminal.TerminalHandler;
import com.fr.decision.webservice.utils.DecisionServiceConstants;
import com.fr.decision.webservice.v10.login.LoginService;
import com.fr.decision.webservice.v10.login.TokenResource;
import com.fr.decision.webservice.v10.user.UserService;
import com.fr.log.FineLoggerFactory;
import com.fr.stable.StringUtils;
import com.fr.stable.web.Device;

import javax.servlet.FilterChain;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Properties;

/**
 * @author fr.open
 * @since 2021/7/12
 */
public class CommonUtils {

    public static String getProperty(Properties props, String key, String defaultValue, boolean allowBlank) {
        String value = props.getProperty(key);
        if (StringUtils.isNotBlank(value)) {
            return value;
        } else {
            if (allowBlank) {
                return defaultValue;
            } else {
                throw new IllegalArgumentException("Property[" + key + "] cann't be blank.");
            }
        }
    }

    public static String getProperty(Properties props, String key, boolean allowBlank) {
        return getProperty(props, key, null, allowBlank);
    }

    public static String getProperty(Properties props, String key) {
        return getProperty(props, key, null, true);
    }

    public static boolean isLogin(HttpServletRequest request) {
        String oldToken = TokenResource.COOKIE.getToken(request);
        return oldToken != null && checkTokenValid(request, (String) oldToken);
    }

    private static boolean checkTokenValid(HttpServletRequest req, String token) {
        try {
            Device device = NetworkHelper.getDevice(req);
            LoginService.getInstance().loginStatusValid(token, TerminalHandler.getTerminal(req, device));
            return true;
        } catch (Exception ignore) {
        }
        return false;
    }

    /**
     * 跳转到过滤器链中的下一个过滤器
     *
     * @param request
     * @param response
     * @param chain
     */
    public static void next(HttpServletRequest request, HttpServletResponse response, FilterChain chain) {
        try {
            chain.doFilter(request, response);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    public static void login(String username, HttpServletRequest request, HttpServletResponse response) {
        try {
            User user = UserService.getInstance().getUserByUserName(username);
            if (user == null) {
                throw new RuntimeException("系统未授权, 当前用户是\"" + username + "\"");
            }
            String token = LoginService.getInstance().login(request, response, username);
            request.setAttribute(DecisionServiceConstants.FINE_AUTH_TOKEN_NAME, token);
        } catch (Exception e) {
            FineLoggerFactory.getLogger().error("sso >> Failed to login with[" + username + "]", e);
            throw new RuntimeException("用户\"" + username +"\"登录失败");
        }
    }

}
